@@ -5,7 +5,6 @@ import os
 import os.path as osp
 import pkgutil
 import re
-import warnings
 from collections import OrderedDict
 from importlib import import_module
 from tempfile import TemporaryDirectory
@@ -56,7 +55,7 @@ def load_state_dict(module, state_dict, strict=False, logger=None):
         state_dict (OrderedDict): Weights.
         strict (bool): whether to strictly enforce that the keys
             in :attr:`state_dict` match the keys returned by this module's
-            :meth:`~torch.nn.Module.state_dict` function. Default: ``False``.
+            :meth:`~torch.nn.Module.state_dict` function. Defaults to False.
         logger (:obj:`logging.Logger`, optional): Logger to log the error
             message. If not specified, print function will be used.
     """
@@ -285,7 +284,7 @@ class CheckpointLoader:
         Args:
             filename (str): checkpoint file name with given prefix
             map_location (str, optional): Same as :func:`torch.load`.
-                Default: None
+                Defaults to None
             logger (str): The logger for message. Defaults to 'current'.
 
         Returns:
@@ -332,7 +331,7 @@ def load_from_http(filename,
             torchvision prefix
         map_location (str, optional): Same as :func:`torch.load`.
         model_dir (string, optional): directory in which to save the object,
-            Default: None
+            Defaults to None
 
     Returns:
         dict or OrderedDict: The loaded checkpoint.
@@ -364,7 +363,7 @@ def load_from_pavi(filename, map_location=None):
     Args:
         filename (str): checkpoint file path with pavi prefix
         map_location (str, optional): Same as :func:`torch.load`.
-          Default: None
+          Defaults to None
 
     Returns:
         dict or OrderedDict: The loaded checkpoint.
@@ -425,9 +424,11 @@ def load_from_torchvision(filename, map_location=None):
     """
     model_urls = get_torchvision_models()
     if filename.startswith('modelzoo://'):
-        warnings.warn(
+        print_log(
             'The URL scheme of "modelzoo://" is deprecated, please '
-            'use "torchvision://" instead', DeprecationWarning)
+            'use "torchvision://" instead',
+            logger='current',
+            level=logging.WARNING)
         model_name = filename[11:]
     else:
         model_name = filename[14:]
@@ -443,7 +444,7 @@ def load_from_openmmlab(filename, map_location=None):
         filename (str): checkpoint file path with open-mmlab or
         openmmlab prefix
         map_location (str, optional): Same as :func:`torch.load`.
-          Default: None
+          Defaults to None
 
     Returns:
         dict or OrderedDict: The loaded checkpoint.
@@ -459,10 +460,11 @@ def load_from_openmmlab(filename, map_location=None):
 
     deprecated_urls = get_deprecated_model_names()
     if model_name in deprecated_urls:
-        warnings.warn(
+        print_log(
             f'{prefix_str}{model_name} is deprecated in favor '
             f'of {prefix_str}{deprecated_urls[model_name]}',
-            DeprecationWarning)
+            logger='current',
+            level=logging.WARNING)
         model_name = deprecated_urls[model_name]
     model_url = model_urls[model_name]
     # check if is url
@@ -504,9 +506,9 @@ def _load_checkpoint(filename, map_location=None, logger=None):
             ``open-mmlab://xxx``. Please refer to ``docs/model_zoo.md`` for
             details.
         map_location (str, optional): Same as :func:`torch.load`.
-           Default: None.
+           Defaults to None.
         logger (:mod:`logging.Logger`, optional): The logger for error message.
-           Default: None
+           Defaults to None
 
     Returns:
         dict or OrderedDict: The loaded checkpoint. It can be either an
@@ -524,7 +526,8 @@ def _load_checkpoint_with_prefix(prefix, filename, map_location=None):
         filename (str): Accept local filepath, URL, ``torchvision://xxx``,
             ``open-mmlab://xxx``. Please refer to ``docs/model_zoo.md`` for
             details.
-        map_location (str | None): Same as :func:`torch.load`. Default: None.
+        map_location (str | None): Same as :func:`torch.load`.
+            Defaults to None.
 
     Returns:
         dict or OrderedDict: The loaded checkpoint.
@@ -594,7 +597,7 @@ def load_checkpoint(model,
         logger (:mod:`logging.Logger` or None): The logger for error message.
         revise_keys (list): A list of customized keywords to modify the
             state_dict in checkpoint. Each item is a (pattern, replacement)
-            pair of the regular expression operations. Default: strip
+            pair of the regular expression operations. Defaults to strip
             the prefix 'module.' by [(r'^module\\.', '')].
 
     Returns:
@@ -668,7 +671,7 @@ def get_state_dict(module, destination=None, prefix='', keep_vars=False):
             module.
         prefix (str): Prefix of the key.
         keep_vars (bool): Whether to keep the variable property of the
-            parameters. Default: False.
+            parameters. Defaults to False.
 
     Returns:
         dict: A dictionary containing a whole state of the module.
@@ -710,13 +713,15 @@ def save_checkpoint(checkpoint,
             Defaults to None. It will be deprecated in future. Please use
             `backend_args` instead.
         backend_args (dict, optional): Arguments to instantiate the
-            preifx of uri corresponding backend. Defaults to None.
+            prefix of uri corresponding backend. Defaults to None.
             New in v0.2.0.
     """
     if file_client_args is not None:
-        warnings.warn(
+        print_log(
             '"file_client_args" will be deprecated in future. '
-            'Please use "backend_args" instead', DeprecationWarning)
+            'Please use "backend_args" instead',
+            logger='current',
+            level=logging.WARNING)
         if backend_args is not None:
             raise ValueError(
                 '"file_client_args" and "backend_args" cannot be set '
